from django.db import models
from django.contrib.auth.models import User


class Skill(models.Model):
    name = models.CharField(max_length=255, default='')
    users = models.ManyToManyField(User, blank=True, related_name="skills")

    class Meta:
        permissions = (
            ('view_skill', 'Read'),
            ('control_skill', 'Control'),
        )

    def __str__(self):
        return self.name



import factory
from .models import Skill

class SkillFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = Skill

    name = factory.Faker('word')

    @factory.post_generation
    def members(self, create, extracted, **kwargs):
        if not create:
            return

        if extracted:
            for member in extracted:
                self.users.add(member)



from django.core.management.base import BaseCommand, CommandError
from djangoldp_skill.factories import SkillFactory
from django.contrib.auth.models import User
import random

class Command(BaseCommand):
    help = 'Mock data'

    def randomMember(self, quantity: int = 10):
        query_set = User.objects.order_by('?')[:quantity]
        return query_set

    def add_arguments(self, parser):
        parser.add_argument('--size', type=int, default=0, help='Number of skill to create')
        parser.add_argument('--sizeof', type=int, default=10, help='Number of members into each skill created')

    def handle(self, *args, **options):
        for i in range(0, options['size']):
            random_member = self.randomMember(options['sizeof']);
            SkillFactory.create(members=random_member);

        self.stdout.write(self.style.SUCCESS('Successful data mock install'))



"""djangoldp skill URL Configuration"""
from django.conf.urls import url

from djangoldp.views import LDPViewSet
from .models import Skill

urlpatterns = [
    url(r'^skills/', LDPViewSet.urls(model=Skill, permission_classes=[], fields=["@id", "name"], nested_fields=[])),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-12-18 12:08
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_skill', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='skill',
            name='user',
        ),
        migrations.AddField(
            model_name='skill',
            name='users',
            field=models.ManyToManyField(blank=True, related_name='skills', to=settings.AUTH_USER_MODEL),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-11-24 14:00
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Skill',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=255)),
                ('user', models.ManyToManyField(blank=True, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (('view_skill', 'Read'), ('control_skill', 'Control')),
            },
        ),
    ]
